<?php
/**
 * Created by PhpStorm.
 * User: rpingot
 * Date: 13.10.2017
 * Time: 16:34
 */

class PresencePdf extends EPdfFactoryDoc
{

    static $monthNames = array('January'=>'Styczeń',
                            'February'=>'Luty',
                            'March'=>'Marzec',
                            'April'=>'Kwiecień',
                            'May'=>'Maj',
                            'June'=>'Czerwiec',
                            'July'=>'Lipiec',
                            'August'=>'Sierpień',
                            'September'=>'Wrzesień',
                            'October'=>'Październik',
                            'November'=>'Listopad',
                            'December'=>'Grudzień',);

    public function init()
    {

        //$this->setTemplate('template-outlines.pdf', 0, 0, 148); //with defining the area to print in
        //override the configured default
        $this->setTcpdfOptions(array('orientation' => 'P', 'format' => 'A4'));
    }

    // the pdf name on creating the (cached) file or downloading.
    //always add the extension '.pdf'
    public function getPdfName()
    {

        $this->pname = 'Lista_Obecności_' . date("Y-m-d-H-i-s") . '.pdf';
        return $this->pname;
    }

    public function initDocInfo()
    {
        $pdf = $this->getPdf();

        $pdf->SetTitle('Lista Obecności');
        $pdf->SetSubject('Lista Obecności');
        $pdf->SetKeywords('Lista Obecności');
    }

    public function renderPdf()
    {
        $this->addPage();
        $this->initMargins();
        $this->initFooter();
        $pdf = $this->getPdf();
        $pdf->SetFont('myriadpro', '', 9);

        $users = $this->getDataItem('chosenUsers');
        $rcp = $this->getDataItem('chosenUsersRCP');
        $wnioski = $this->getDataItem('chosenUsersWniosek');
        $summaryHours = $this->getDataItem('chosenUsersRCPSummary');

        $pdf->SetHeaderMargin(0);
        $pdf->SetFooterMargin(0);
        $pdf->setPrintFooter(true);

        $html = '';
        $len = count($users);
        foreach ($users as $user) {
            $specifiedRCP = array_filter($rcp, function ($element) use (&$user) {
                return ($element->userid == $user->uid);
            });
            $specifiedWnioski = array_filter($wnioski, function ($element) use (&$user) {
                return ($element->userid == $user->uid);
            });
            $specifiedSummaryHours = array_filter($summaryHours,function ($element) use (&$user){
                return ($element->uid == $user->uid);
            });
            $html = $this->createTableForUser($user, $specifiedRCP, $specifiedWnioski,$specifiedSummaryHours);
            $pdf->writeHTML($html, false, false, false, false, '');
            if ($user !== end($users))
                $pdf->addPage();
        }


    }

    public function createTableForUser($user, $rcp, $wnioski,$summaryHours)
    {
        $endDate = $this->getDataItem('chosenDateInfo');
        $tbl = '<style>
                 table{
                 border: 2px solid black;
                 width: 100%;
                 }
                 td,th{
                 height: 18px;
                 font-size: 1.2em;
                 text-align: center;
                 border: 1px solid black;
                 }
                 p{
                 font-size: 1.2em;
                 }
                </style>
                <table>
                <tbody>
                <tr>
                <td style="text-align: center;" colspan="7">Lista obecności - '. self::$monthNames[$endDate['month']] .' '.$endDate['year'].'</td>
                </tr>
                <tr>
                <td colspan="7" style="text-align: left;">Pracownik: '.User::nazwiskoImieSpecific($user->uid).'</td>
                </tr>
                <tr>
                <td style="width: 8%;">Dzień</td>
                <td style="width: 14%;">Wejście</td>
                <td style="width: 20%;">Podpis</td>
                <td style="width: 14%;">Wyjście</td>
                <td style="width: 20%;">Podpis</td>
                <td style="width: 10%;">Ilość Godzin</td>
                <td style="width: 14%;">Uwagi</td>
                </tr>';

        $holidayIntervals = array();
        if (!empty($wnioski)){
            foreach ($wnioski as $wniosek){
                $holidayIntervals[$wniosek->wid.' '.strtotime($wniosek->od) .' '. strtotime($wniosek->do)] = $wniosek->rodzaj->nazwa;
            }
        }

        for ($day = 1; $day <= $endDate['mday']; $day++) {
            $line = '';
            $iterationDay = strtotime($day.'.'.$endDate['mon'].'.'.$endDate['year']);
            $eventName = $this->holidayInInterval($iterationDay,$holidayIntervals);
            $iterationDayInfo = getdate($iterationDay);
            $iterationRCP = array_filter($rcp,function ($element)use($iterationDay){
                return (date('Y-m-d',strtotime($element->data)) == date('Y-m-d',$iterationDay) );
            });
            if ($iterationDayInfo['weekday'] == 'Saturday' || $iterationDayInfo['weekday'] == 'Sunday'){
                $line .= '<tr style="background-color: lightgray">';
            }else{
                $line .= '<tr>';
            }
            $line .= '<td>'.$day.'</td>';
            if (!empty($eventName))
            {
                $line .=  '<td colspan="6" style="text-align: center">'.$eventName.'</td>';
            }elseif (!empty($iterationRCP)){
                $valueArray =array();
                foreach ($iterationRCP as $value){
                    if (array_key_exists('in',$valueArray)){
                        $valueArray['in'] .= '<br>'.$value->we_czas;
                    }else{
                        $valueArray['in'] = $value->we_czas;
                    }
                    if (array_key_exists('out',$valueArray)){
                        $valueArray['out'] .= '<br>'.$value->wy_czas;
                    }else{
                        $valueArray['out'] = $value->wy_czas;
                    }
                    if(!empty($value->wy_czas)){
                        if (array_key_exists('sum',$valueArray)){
                            $valueArray['sum'] += $this->countHoursEntry($value->we_czas,$value->wy_czas);
                        }else{
                            $valueArray['sum'] = $this->countHoursEntry($value->we_czas,$value->wy_czas);
                        }
                    }

                }
                $line .= '<td>'.$valueArray['in'].'</td>';
                $line .= '<td></td>';
                $line .= '<td>'.$valueArray['out'].'</td>';
                $line .= '<td></td>';
                if (array_key_exists('sum',$valueArray)){
                    $line .= '<td>'.Time::secondsToHours($valueArray['sum']).'</td>';
                }else{
                    $line .= '<td></td>';
                }
                $line .= '<td></td>';
            }else{
                $line .= '<td></td>';
                $line .= '<td></td>';
                $line .= '<td></td>';
                $line .= '<td></td>';
                $line .= '<td></td>';
                $line .= '<td></td>';
            }
            $line.='</tr>';
            $tbl .= $line;
        }

        $tbl .='</tbody></table><p>&nbsp;</p>';

        if (!empty($summaryHours)){
            $summaryHoursReference = array_pop($summaryHours);
            $summaryHoursAll = $summaryHoursReference['wszystkich'];
            $total = Time::secondsToHours($summaryHoursAll);
        }else{
            $total = '00:00';
        }
        $tbl .= '<p style="text-align: right;">Ilość godzin w miesiącu:'.$total.'</p>';

        return $tbl;

    }

    private function holidayInInterval($date,$intervals){
        $holidayBetween = '';
        if (!empty($intervals)){
            foreach ($intervals as $key=>$value){
                $explodedInterval = explode(' ',$key);
                if($explodedInterval[1] <= $date && $explodedInterval[2] >= $date){
                    $holidayBetween .= (empty($holidayBetween)) ? $value : ', '.$value;
                }
            }
        }
        return $holidayBetween;
    }

    public function countHoursEntry($in,$out){
        $timeIn = strtotime($in);
        $timeOut = strtotime($out);
        if ($timeIn > $timeOut)
        {
            $hours = 24*60*60 - ($timeIn -$timeOut);
        }else{
            $hours = $timeOut - $timeIn;
        }
        return $hours;
    }

}



/*
 * Pattern
 *
 *
 <table>
<tbody>
<tr>
<td style="text-align: center;" colspan="7">Lista obecności - Chosen Month+Year</td>
</tr>
<tr>
<td colspan="7">Pracownik: Username</td>
</tr>
<tr>
<td style="width: 6%;">Dzień</td>
<td style="width: 14%;">Wejście</td>
<td style="width: 20%;">Podpis</td>
<td style="width: 14%;">Wyjście</td>
<td style="width: 20%;">Podpis</td>
<td style="width: 10%;">Ilość Godzin</td>
<td style="width: 15%;">Uwagi</td>
</tr>
</tbody>
</table>
<p>&nbsp;</p>
   */